@@ -1,18 +1,17 @@
 # Copyright (c) 2010, 2011, Canonical Ltd
 #
 # This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, version 3 only.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-# GNU Affero General Public License version 3 (see the file LICENSE).
+# GNU Lesser General Public License version 3 (see the file LICENSE).
 
 """Read / Write an OOPS dict as an rfc822 formatted message.
 
@@ -34,7 +33,7 @@ the python-oops api docs for more information about these variables):
 * tb_text: A text version of the traceback.
 * username: The user associated with the request.
 * url: The URL for the failed request.
-* req_vars: The request variables.
+* req_vars: The request variables. Either a list of 2-tuples or a dict.
 * branch_nick: A name for the branch of code that was running when the report
   was triggered.
 * revno: The revision that the branch was at.
@@ -123,6 +122,7 @@ def read(fp):
                 req_vars.append([urllib.unquote(key), urllib.unquote(value)])
             elif is_traceback(line):
                 break
+    req_vars = dict(req_vars)
 
     # The rest is traceback.
     tb_text = ''.join([first_tb_line] + list(lines))
@@ -196,7 +196,11 @@ def to_chunks(report):
     chunks.append('\n')
     safe_chars = ';/\\?:@&+$, ()*!'
     if 'req_vars' in report:
-        for key, value in report['req_vars']:
+        try:
+            items = sorted(report['req_vars'].items())
+        except AttributeError:
+            items = report['req_vars']
+        for key, value in items:
             chunks.append('%s=%s\n' % (
                     urllib.quote(_safestr(key), safe_chars),
                     urllib.quote(_safestr(value), safe_chars)))
